::In this folder are the examples of devices that can be loaded into MicroManager using PyDevice.

::To test one out without hardware, the files with the 'example' prefix are recommended.

::This folder contains:

- galvo_scanner: Controller for a laser-scanning microscope with two galvo mirrors controlled by a National Instruments
  data acquisition card (nidaq).
- nidaq_gain: A device that controls the voltage of a PMT gain using a NI data acquisition card.